@@ -230,8 +230,7 @@ def download():
     )
 
     parser.add_argument(
-        "--country",
-        "-cty",
+        "country",
         type=str,
         default="Australia",
         help="Name of the country for which the reference data to download",
